types.go
changeset 138 23d3a518d0ad
parent 136 1af0a6199a93
child 147 b682706e2f31
--- a/types.go	Wed Apr 19 09:30:47 2017 +0200
+++ b/types.go	Wed Apr 19 10:43:38 2017 +0200
@@ -5,13 +5,13 @@
 Licensed under the MIT license.  Please see the LICENSE file is this directory.
 */
 
-package gondole
+package madon
 
 import (
 	"time"
 )
 
 // Client contains data for a gondole client application
 type Client struct {
 	Name        string // Name of the client
 	ID          string // Application ID
@@ -23,9 +23,7 @@
 }
 
 /*
-Entities:
-
-Everything manipulated/returned by the API
+Entities - Everything manipulated/returned by the API
 */
 
 // Account represents a Mastodon account entity
@@ -5,13 +5,13 @@
 )
 
-// Client contains data for a gondole client application
+// Client contains data for a madon client application
 type Client struct {
 	Name        string // Name of the client